// Copyright 2018 The Cockroach Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
// implied. See the License for the specific language governing
// permissions and limitations under the License.

package types

import (
	"testing"

	"github.com/lib/pq/oid"
)

func TestArraysHaveOids(t *testing.T) {
	for _, typ := range AnyNonArray {
		if ok, _ := IsValidArrayElementType(typ); !ok {
			continue
		}

		if (TArray{Typ: typ}).Oid() == oid.Oid(0) {
			t.Errorf("%s[] does not have a valid OID", typ)
		}
	}
}
